# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFirewallSettingsResult',
    'AwaitableGetFirewallSettingsResult',
    'get_firewall_settings',
    'get_firewall_settings_output',
]

@pulumi.output_type
class GetFirewallSettingsResult:
    """
    A collection of values returned by getFirewallSettings.
    """
    def __init__(__self__, default_firewall_ids=None, id=None):
        if default_firewall_ids and not isinstance(default_firewall_ids, dict):
            raise TypeError("Expected argument 'default_firewall_ids' to be a dict")
        pulumi.set(__self__, "default_firewall_ids", default_firewall_ids)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="defaultFirewallIds")
    def default_firewall_ids(self) -> 'outputs.GetFirewallSettingsDefaultFirewallIdsResult':
        return pulumi.get(self, "default_firewall_ids")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetFirewallSettingsResult(GetFirewallSettingsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFirewallSettingsResult(
            default_firewall_ids=self.default_firewall_ids,
            id=self.id)


def get_firewall_settings(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFirewallSettingsResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getFirewallSettings:getFirewallSettings', __args__, opts=opts, typ=GetFirewallSettingsResult).value

    return AwaitableGetFirewallSettingsResult(
        default_firewall_ids=pulumi.get(__ret__, 'default_firewall_ids'),
        id=pulumi.get(__ret__, 'id'))
def get_firewall_settings_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFirewallSettingsResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getFirewallSettings:getFirewallSettings', __args__, opts=opts, typ=GetFirewallSettingsResult)
    return __ret__.apply(lambda __response__: GetFirewallSettingsResult(
        default_firewall_ids=pulumi.get(__response__, 'default_firewall_ids'),
        id=pulumi.get(__response__, 'id')))
